@@ -16,9 +16,11 @@
  ***************************************************************************/
 
 #include "config.h"
-#include <stdio.h>
+
 #include <stdlib.h>
 
+#include <new>
+
 #include <QApplication>
 #include <QIcon>
 #include <QLabel>
@@ -336,7 +338,7 @@ void Kwave::PlayBackDialog::setSupportedDevices(QStringList devices)
 		    parent = item;
 		} else if (parent) {
 		    // new leaf, add to the parent
-		    item = new QTreeWidgetItem(parent);
+		    item = new(std::nothrow) QTreeWidgetItem(parent);
 		    Q_ASSERT(item);
 		    if (item) {
 			item->setText(0, token);
@@ -352,7 +354,7 @@ void Kwave::PlayBackDialog::setSupportedDevices(QStringList devices)
 		    }
 		} else {
 		    // new root node
-		    item = new QTreeWidgetItem(listDevices);
+		    item = new(std::nothrow) QTreeWidgetItem(listDevices);
 		    Q_ASSERT(item);
 		    if (item) {
 			item->setText(0, token);
@@ -647,7 +649,7 @@ void Kwave::PlayBackDialog::selectPlaybackDevice()
         dlg->selectUrl(QUrl(_("file:") + m_playback_params.device));
     else
         dlg->selectUrl(QUrl(_("file:/dev/*")));
-    if (dlg->exec() == QDialog::Accepted) {
+    if ((dlg->exec() == QDialog::Accepted) && dlg) {
 	QString new_device = dlg->selectedUrl().fileName();
 	// selected new device
 	if (cbDevice) cbDevice->setEditText(new_device);
