@@ -18,17 +18,18 @@
 #include "config.h"
 
 #include <errno.h>
-#include <limits.h>
 #include <math.h>
-#include <new>
-#include <stdio.h>
 #include <stdlib.h>
 
+#include <limits>
+#include <new>
+
 #include <QApplication>
 #include <QColor>
 #include <QFutureSynchronizer>
 #include <QImage>
 #include <QMutexLocker>
+#include <QPointer>
 #include <QString>
 #include <QtConcurrentRun>
 
@@ -103,7 +104,8 @@ QStringList *Kwave::SonagramPlugin::setup(QStringList &previous_params)
     // try to interprete the list of previous parameters, ignore errors
     if (previous_params.count()) interpreteParameters(previous_params);
 
-    Kwave::SonagramDialog *dlg = new(std::nothrow) Kwave::SonagramDialog(*this);
+    QPointer<Kwave::SonagramDialog> dlg =
+	new(std::nothrow) Kwave::SonagramDialog(*this);
     Q_ASSERT(dlg);
     if (!dlg) return Q_NULLPTR;
 
@@ -112,8 +114,8 @@ QStringList *Kwave::SonagramPlugin::setup(QStringList &previous_params)
     dlg->setTrackChanges(m_track_changes);
     dlg->setFollowSelection(m_follow_selection);
 
-    if (dlg->exec() == QDialog::Accepted) {
-	result = new QStringList();
+    if ((dlg->exec() == QDialog::Accepted) && dlg) {
+	result = new(std::nothrow) QStringList();
 	Q_ASSERT(result);
 	if (result) dlg->parameters(*result);
     };
@@ -138,7 +140,6 @@ int Kwave::SonagramPlugin::interpreteParameters(QStringList &params)
 
     param = params[1];
     m_window_type = Kwave::WindowFunction::findFromName(param);
-    if (!ok) return -EINVAL;
 
     param = params[2];
     m_color = (param.toUInt(&ok) != 0);
@@ -168,7 +169,7 @@ int Kwave::SonagramPlugin::start(QStringList &params)
 
     Kwave::SignalManager &sig_mgr = signalManager();
 
-    // interprete parameter list and abort if it contains invalid data
+    // interpret parameter list and abort if it contains invalid data
     int result = interpreteParameters(params);
     if (result) return result;
 
@@ -198,7 +199,7 @@ int Kwave::SonagramPlugin::start(QStringList &params)
     if (m_slices > MAX_SLICES) m_slices = MAX_SLICES;
 
     /* limit selection to INT_MAX samples (limitation of the cache index) */
-    if ((length / m_fft_points) >= INT_MAX) {
+    if ((length / m_fft_points) >= std::numeric_limits<int>::max()) {
 	Kwave::MessageBox::error(parentWidget(),
 	                         i18n("File or selection too large"));
 	return -EFBIG;
